{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% blocktrans trimmed %}
    "Manage" an existing volume from a Cinder host. This will make the volume visible within
    OpenStack.
    <br>
    <br>
    This is equivalent to the <tt>cinder manage</tt> command.
    {% endblocktrans %}
  </p>
{% endblock %}
